@@ -13,6 +13,7 @@ from FreeTAKServer.controllers.DatabaseControllers import APIUsersController
 from FreeTAKServer.controllers.DatabaseControllers import ExCheckController
 from FreeTAKServer.controllers.DatabaseControllers import ExCheckChecklistController
 from FreeTAKServer.controllers.DatabaseControllers import API_call_controller
+from FreeTAKServer.controllers.DatabaseControllers import _VideoTableController
 from FreeTAKServer.controllers.DatabaseControllers.table_controllers import ActiveFederationsController, UserTableController, FederationsController
 import FreeTAKServer.model.SQLAlchemy.CoTTables.Archive
 import FreeTAKServer.model.SQLAlchemy.CoTTables._Group
@@ -60,6 +61,7 @@ class DatabaseController:
         self.UserTableController = UserTableController()
         self.SystemUserTableController = system_user_table_controller.SystemUserTableController()
         self.VideoStreamTableController = VideoStreamTableController.VideoStreamTableController()
+        self._VideoTableController = _VideoTableController._VideoTableController()
         self.EventTableController = EventTableController.EventTableController()
         self.APIUserController = APIUsersController.APIUsersController()
         self.ActiveEmergencysController = ActiveEmergencysController.ActiveEmergencysController()
@@ -80,7 +82,7 @@ class DatabaseController:
         if engine.dialect.has_table(engine, 'SystemUser') == False:
             Base.metadata.create_all(engine)
             tempsession = sessionmaker(bind=engine)()
-            tempsession.add(FreeTAKServer.model.SQLAlchemy.system_user.SystemUser(uid="1", name="admin", password="password", token="token"))
+            tempsession.add(FreeTAKServer.model.SQLAlchemy.system_user.SystemUser(uid="1", name="admin", password="password", token="token", device_type="mobile"))
             tempsession.commit()
             tempsession.close()
             return engine
@@ -173,7 +175,7 @@ class DatabaseController:
                 self.session.rollback()
                 self.session.close()
                 self.session = self.create_Session()
-                obj = self.query_CoT(f'uid == "{args["CoT"].uid}"')[0]
+                obj = self.query_CoT(f'uid = "{args["CoT"].uid}"')[0]
                 self.session.delete(obj)
                 self.session.commit()
                 return self._create(controller=self.UserTableController, **args)
@@ -181,6 +183,7 @@ class DatabaseController:
                 self.session.rollback()
                 self.session.close()
                 self.session = self.create_Session()
+                raise Exception(e)
     def remove_user(self, query="1=1"):
         '''
         :param query: this parameter will be used to select which datapackages are deleted
@@ -198,15 +201,17 @@ class DatabaseController:
         try:
             return self._create(controller=self.SystemUserTableController, **args)
         except Exception as e:
+            print(e)
             self.session.rollback()
             self.session.commit()
+            raise Exception(e)
     def remove_systemUser(self, query="1=1"):
         return self._remove(controller=self.SystemUserTableController, query=query)
 
     def query_systemUser(self, query="1=1", column=['*']):
         return self._query(controller=self.SystemUserTableController, query=query, columns=column)
 
-    def update_systemUser(self, column_value=dict(), query="1=1"):
+    def update_systemUser(self, column_value=dict, query="1=1"):
         return self._update(controller=self.SystemUserTableController, query=query, column_value=column_value)
 
     def create_videostream(self, **args):
@@ -217,12 +222,28 @@ class DatabaseController:
         :param query: this parameter will be used to select which datapackages are deleted
         :return: 1 on success
         '''
-        return self._remove(controller=self.VideoStreamTableController, query=query)
+        return self._remove(controller=self._VideoTableController, query=query)
 
     def query_videostream(self, query="1=1", column=['*']):
-        return self._query(controller=self.VideoStreamTableController, query=query, columns=column)
+        return self._query(controller=self._VideoTableController, query=query, columns=column)
 
     def update_videostream(self, column_value=dict(), query="1=1"):
+        return self._update(controller=self._VideoTableController, query=query, column_value=column_value)
+
+    def create_vide(self, **args):
+        return self._create(controller=self._VideoTableController, **args)
+
+    def remove_vide(self, query="1=1"):
+        '''
+        :param query: this parameter will be used to select which datapackages are deleted
+        :return: 1 on success
+        '''
+        return self._remove(controller=self.VideoStreamTableController, query=query)
+
+    def query_video(self, query="1=1", column=['*']):
+        return self._query(controller=self._VideoTableController, query=query, columns=column)
+
+    def update_video(self, column_value=dict(), query="1=1"):
         return self._update(controller=self.VideoStreamTableController, query=query, column_value=column_value)
 
     def create_CoT(self, object):
@@ -235,7 +256,7 @@ class DatabaseController:
             try:
                 session.rollback()
                 session.close()
-                obj = self.query_CoT(f'uid == "{object.uid}"')[0]
+                obj = self.query_CoT(f'uid = "{object.uid}"')[0]
                 newobj = self.EventTableController.convert_model_to_row(object)
                 self.session.delete(obj)
                 self.session.commit()
@@ -282,8 +303,11 @@ class DatabaseController:
             session = self.create_Session()
             self.ActiveEmergencysController.create(session, object)
         except Exception as e:
+            print(e)
             session.rollback()
             session.close()
+            raise Exception(e)
+
     def remove_ActiveEmergency(self, query="1=1"):
         return self._remove(controller=self.ActiveEmergencysController, query=query)
 
